import * as i0 from '@angular/core';
import { NgModule, EventEmitter, TemplateRef, ViewChild, Input, Output, ContentChildren, Component } from '@angular/core';
import { CommonModule, AsyncPipe, NgIf, NgForOf, NgTemplateOutlet } from '@angular/common';
import { fromEvent, merge, BehaviorSubject } from 'rxjs';
import { debounceTime, distinctUntilChanged, tap } from 'rxjs/operators';
import { SortOrdersDto, SearchFilterTypesDto } from '@meshmakers/octo-services';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort, MatSortHeader } from '@angular/material/sort';
import { MatButton, MatIconButton } from '@angular/material/button';
import { MatCell, MatCellDef, MatColumnDef, MatHeaderCell, MatRow, MatRowDef, MatTable, MatHeaderCellDef, MatHeaderRow, MatHeaderRowDef } from '@angular/material/table';
import { MatFormField, MatLabel } from '@angular/material/form-field';
import { MatIcon } from '@angular/material/icon';
import { MatInput } from '@angular/material/input';
import { MatProgressBar } from '@angular/material/progress-bar';
import { MatToolbar } from '@angular/material/toolbar';
import { MatMenu, MatMenuItem, MatMenuTrigger } from '@angular/material/menu';
import { MatListItemIcon } from '@angular/material/list';
import { RouterLink } from '@angular/router';

class ListElementModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: ListElementModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.14", ngImport: i0, type: ListElementModule, imports: [CommonModule] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: ListElementModule, imports: [CommonModule] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: ListElementModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [CommonModule]
                }]
        }] });

class OctoListNavigationDataInfo {
    skip;
    take;
    searchFilter;
    sort;
    constructor() {
        this.skip = 0;
        this.take = 10;
    }
}
class OctoListNavigationOptions {
    language;
    searchFilterType;
    searchFilterAttributePaths;
    constructor() {
        this.language = null;
    }
}
class OctoListNavigation {
    paginator;
    sort;
    searchBox;
    octoOptions;
    loadDataRequest = new EventEmitter();
    lastSortDirection;
    lastSortField;
    lastSearchText;
    constructor(paginator, sort, searchBox, octoOptions) {
        this.paginator = paginator;
        this.sort = sort;
        this.searchBox = searchBox;
        this.octoOptions = octoOptions;
        this.lastSortDirection = null;
        this.lastSortField = null;
        this.lastSearchText = null;
    }
    get loadDataInfo() {
        const filterString = this.searchBox?.nativeElement.value;
        const sortField = this.sort.active;
        const sortDirection = this.sort.direction;
        let filter = null;
        if (filterString && this.octoOptions) {
            filter = {
                language: this.octoOptions.language,
                searchTerm: filterString,
                type: this.octoOptions.searchFilterType,
                attributePaths: this.octoOptions.searchFilterAttributePaths
            };
        }
        const sort = [];
        if (sortField && sortDirection) {
            sort.push({
                attributePath: sortField,
                sortOrder: sortDirection === 'asc' ? SortOrdersDto.AscendingDto : SortOrdersDto.DescendingDto
            });
        }
        return {
            skip: this.paginator.pageIndex * this.paginator.pageSize,
            take: this.paginator.pageSize,
            searchFilter: filter,
            sort
        };
    }
    init() {
        if (this.searchBox) {
            // server-side search
            fromEvent(this.searchBox.nativeElement, 'keyup')
                .pipe(debounceTime(500), distinctUntilChanged(), tap(() => {
                this.paginator.pageIndex = 0;
                if (!this.searchBox) {
                    return;
                }
                const searchText = this.searchBox.nativeElement.value;
                if (!this.lastSearchText && searchText) {
                    this.lastSortDirection = this.sort.direction;
                    this.lastSortField = this.sort.active;
                    // Reset sorting to see the score rating (default sorting returned from server)
                    this.sort.sort({ id: '', start: 'asc', disableClear: false });
                }
                this.lastSearchText = searchText;
                if (!searchText && this.lastSortField) {
                    if (this.lastSortDirection === 'asc') {
                        this.sort.sort({
                            id: this.lastSortField,
                            start: 'asc',
                            disableClear: true
                        });
                    }
                    else if (this.lastSortDirection === 'desc') {
                        this.sort.sort({
                            id: this.lastSortField,
                            start: 'desc',
                            disableClear: true
                        });
                    }
                }
                this.loadData();
            }))
                .subscribe();
        }
        // reset the paginator after sorting
        this.sort.sortChange.subscribe(() => (this.paginator.pageIndex = 0));
        merge(this.sort.sortChange, this.paginator.page)
            .pipe(tap(() => {
            this.loadData();
        }))
            .subscribe();
    }
    loadData() {
        this.loadDataRequest.emit(this.loadDataInfo);
    }
}

function getDisplayName(column) {
    return column.displayName ?? column.dataKey;
}

class MmOctoTableComponent {
    dataSource;
    cellTemplates;
    templateMap = new Map();
    actionColumns = [];
    leftToolbarActions = [];
    optionActions = [];
    searchFilterColumns = [];
    currentId = '';
    defaultSortColumn = '';
    rowIsClickable = true;
    pageSizeOptions = [5, 10, 20, 50];
    selectedPageSize = 5;
    rowClicked = new EventEmitter();
    searchFilterStringUpdated = new EventEmitter();
    selectedRowId = '';
    actionColumnClick = new EventEmitter();
    set columns(cols) {
        if (cols === null || cols === undefined || cols.length === 0) {
            this._columns = [];
            return;
        }
        this._columns = [];
        for (const column of cols) {
            if (typeof column === 'string') {
                this._columns.push({ dataKey: column });
            }
            else {
                this._columns.push(column);
            }
        }
    }
    get columns() {
        return this._columns;
    }
    _columns = [];
    selectedRow = null; // Track the selected row
    selectedPageSizeSubject = new BehaviorSubject(this.selectedPageSize);
    paginator;
    sort;
    input;
    get columnNames() {
        return this._columns.map((c) => getDisplayName(c));
    }
    loading = false;
    isMobile;
    constructor() {
        this.isMobile = false;
    }
    ngOnInit() {
        this.selectedPageSizeSubject.next(this.selectedPageSize);
        if (!this.dataSource) {
            throw new Error('No dataSource provided');
        }
        this.checkSelectedRow();
    }
    ngAfterContentInit() {
        // Build a map from template reference name to TemplateRef
        this.templateMap.clear();
        if (this.cellTemplates) {
            this.cellTemplates.forEach((template) => {
                // Try to get the reference name from the template
                const refName = template._declarationTContainer?.localNames?.[0];
                if (refName) {
                    this.templateMap.set(refName, template);
                }
            });
        }
    }
    ngAfterViewInit() {
        if (this.sort && this.input && this.paginator) {
            fromEvent(this.input.nativeElement, 'keyup')
                .pipe(debounceTime(500), distinctUntilChanged(), tap(() => {
                // server-side search
                if (this.paginator) {
                    this.paginator.pageIndex = 0;
                }
                this.searchFilterStringUpdated.emit(this.input?.nativeElement?.value ?? '');
                this.loadData();
            }))
                .subscribe();
            // reset the paginator after sorting
            this.sort.sortChange.subscribe(() => {
                if (this.paginator)
                    this.paginator.pageIndex = 0;
            });
            merge(this.sort.sortChange, this.paginator.page)
                .pipe(tap(() => {
                this.loadData();
            }))
                .subscribe();
        }
    }
    loadData() {
        if (!this.input || !this.sort) {
            return;
        }
        const filterString = this.input.nativeElement.value;
        const field = this.sort.active;
        const direction = this.sort.direction;
        let filter = null;
        if (filterString) {
            filter = {
                type: SearchFilterTypesDto.AttributeFilterDto,
                attributePaths: this.searchFilterColumns,
                searchTerm: filterString
            };
        }
        const sort = [];
        if (field) {
            sort.push({
                attributePath: field,
                sortOrder: direction === 'asc' ? SortOrdersDto.AscendingDto : SortOrdersDto.DescendingDto
            });
        }
        if (this.paginator) {
            this.dataSource?.loadData(this.paginator.pageIndex * this.paginator.pageSize, this.paginator.pageSize, filter, null, sort);
        }
    }
    encodeURIComponent = encodeURIComponent;
    accessElement(element, column) {
        if (column.templateName) {
            return element;
        }
        if (column.dataKey.indexOf('.') === -1) {
            return element[column.dataKey];
        }
        const keys = column.dataKey.split('.');
        let value = element;
        for (const key of keys) {
            value = value[key];
        }
        return value;
    }
    selectedPageSizeChanged($event) {
        console.log($event.pageSize);
        this.selectedPageSizeSubject.next($event.pageSize);
    }
    getActionColumnNames() {
        return this.actionColumns.map((ac) => ac.columnName);
    }
    onRowClick(row) {
        if (this.rowIsClickable) {
            this.selectedRow = row; // Set the clicked row as the selected one
            this.rowClicked.emit(row); // Emit the clicked row data
        }
    }
    isRowSelected(row) {
        return this.selectedRow === row; // Check if the row is selected
    }
    checkSelectedRow() {
        // @ts-expect-error jnu
        this.dataSource.connect(null).subscribe((data) => {
            for (const entry of data) {
                if (entry.rtId === this.selectedRowId) {
                    this.onRowClick(entry);
                }
            }
        });
    }
    emitRowData(data) {
        this.actionColumnClick.emit(data);
    }
    // Predicate for rows with optionActions
    hasOptionActions = (_row) => {
        return this.optionActions.length > 0;
    };
    // Predicate for rows with actionColumns but no optionActions
    hasActionColumns = () => {
        return this.actionColumns.length > 0 || this.optionActions.length > 0;
    };
    getDisplayName = getDisplayName;
    getTemplate(templateName) {
        return this.templateMap.get(templateName);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: MmOctoTableComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.14", type: MmOctoTableComponent, isStandalone: true, selector: "mm-octo-table", inputs: { dataSource: "dataSource", actionColumns: "actionColumns", leftToolbarActions: "leftToolbarActions", optionActions: "optionActions", searchFilterColumns: "searchFilterColumns", currentId: "currentId", defaultSortColumn: "defaultSortColumn", rowIsClickable: "rowIsClickable", pageSizeOptions: "pageSizeOptions", selectedPageSize: "selectedPageSize", selectedRowId: "selectedRowId", columns: "columns" }, outputs: { rowClicked: "rowClicked", searchFilterStringUpdated: "searchFilterStringUpdated", actionColumnClick: "actionColumnClick" }, queries: [{ propertyName: "cellTemplates", predicate: TemplateRef }], viewQueries: [{ propertyName: "paginator", first: true, predicate: MatPaginator, descendants: true }, { propertyName: "sort", first: true, predicate: MatSort, descendants: true }, { propertyName: "input", first: true, predicate: ["input"], descendants: true }], ngImport: i0, template: "<div>\n  <mat-progress-bar *ngIf=\"loading || (dataSource?.loading$ | async)\" mode=\"indeterminate\"></mat-progress-bar>\n</div>\n\n<mat-toolbar class=\"octo-toolbar octo-detail-toolbar\">\n  @for (toolbarAction of leftToolbarActions; track toolbarAction) {\n  <button\n    mat-flat-button\n    routerLink=\"{{ toolbarAction.route }}\"\n    type=\"button\"\n    [disabled]=\"!toolbarAction.isDisabled ? false : (toolbarAction.isDisabled | async)\"\n  >\n    @if (toolbarAction?.svgIconName) {\n    <mat-icon class=\"svg-icon\" svgIcon=\"{{ toolbarAction.svgIconName }}\" matListItemIcon></mat-icon>\n    } @if (toolbarAction?.iconName) {\n    <mat-icon class=\"material-symbols-outlined\">{{ toolbarAction.iconName }}</mat-icon>\n    }\n    {{ toolbarAction.actionText }}\n  </button>\n  }\n\n  <div class=\"octo-spacer\"></div>\n\n  <div class=\"octo-toolbar-search\">\n    <mat-form-field appearance=\"outline\">\n      <mat-label>\n        <mat-icon class=\"material-symbols-outlined\">search</mat-icon>\n        Search\n      </mat-label>\n      <input #input matInput [disabled]=\"loading\" />\n    </mat-form-field>\n  </div>\n</mat-toolbar>\n\n<mat-table\n  [class.isMobile]=\"isMobile\"\n  [dataSource]=\"dataSource\"\n  class=\"mat-elevation-z8 table-container\"\n  mat-table\n  matSort\n  matSortActive=\"{{ defaultSortColumn }}\"\n  matSortDirection=\"asc\"\n  matSortDisableClear=\"true\"\n>\n  <ng-container *ngFor=\"let column of columns\" [matColumnDef]=\"getDisplayName(column)\">\n    <mat-header-cell *matHeaderCellDef mat-sort-header> {{ getDisplayName(column) }}</mat-header-cell>\n    <mat-cell *matCellDef=\"let element\">\n      <span *ngIf=\"isMobile\">{{ getDisplayName(column)}:</span>\n      @if (column.templateName) {\n      <ng-container *ngTemplateOutlet=\"getTemplate(column.templateName); context: { $implicit: element }\"> </ng-container>\n      } @else {\n      {{ accessElement(element, column) }}\n      }\n    </mat-cell>\n  </ng-container>\n\n  <!-- Consolidated Action Column with multiple buttons -->\n  <ng-container matColumnDef=\"actions\">\n    <mat-header-cell *matHeaderCellDef>Actions</mat-header-cell>\n    <mat-cell *matCellDef=\"let element\">\n      @for (column of actionColumns; track column) {\n      <ng-container>\n        <button mat-button (click)=\"emitRowData({ action: column.columnName, id: encodeURIComponent(element[currentId]), entry: element })\">\n          <mat-icon *ngIf=\"column?.svgIconName\" class=\"svg-icon\" svgIcon=\"{{ column.svgIconName }}\" matListItemIcon></mat-icon>\n          <mat-icon *ngIf=\"column?.iconName\" class=\"material-symbols-outlined\">{{ column.iconName }}</mat-icon>\n        </button>\n      </ng-container>\n      }\n\n      <!-- Options menu with additional actions -->\n      @if (optionActions.length > 0) {\n      <button mat-icon-button [matMenuTriggerFor]=\"menu\" aria-label=\"Options\">\n        <mat-icon class=\"material-symbols-outlined\">more_vert</mat-icon>\n      </button>\n      }\n\n      <mat-menu #menu=\"matMenu\">\n        @for (optionAction of optionActions; track optionAction) {\n        <ng-container>\n          <button\n            mat-menu-item\n            (click)=\"emitRowData({ action: optionAction.columnName, id: encodeURIComponent(element[currentId]), entry: element })\"\n          >\n            @if (optionAction?.svgIconName) {\n            <mat-icon class=\"svg-icon\" svgIcon=\"{{ optionAction.svgIconName }}\" matListItemIcon></mat-icon>\n            } @if (optionAction?.iconName) {\n            <mat-icon class=\"material-symbols-outlined\">{{ optionAction.iconName }}</mat-icon>\n            }\n            {{ optionAction.columnName }}\n          </button>\n        </ng-container>\n        }\n      </mat-menu>\n    </mat-cell>\n  </ng-container>\n\n  @if (hasActionColumns()) {\n  <mat-header-row *matHeaderRowDef=\"columnNames.concat(['actions'])\"></mat-header-row>\n  <mat-row *matRowDef=\"let row; columns: columnNames.concat(['actions'])\"></mat-row>\n  } @else {\n  <mat-header-row *matHeaderRowDef=\"columnNames\"></mat-header-row>\n  <mat-row *matRowDef=\"let row; columns: columnNames\"></mat-row>\n  }\n</mat-table>\n\n<mat-paginator\n  [length]=\"dataSource?.totalCount$ | async\"\n  (page)=\"selectedPageSizeChanged($event)\"\n  [pageSizeOptions]=\"pageSizeOptions\"\n  [pageSize]=\"selectedPageSizeSubject.getValue()\"\n></mat-paginator>\n", styles: [".table-container{display:block;width:100%;max-height:70vh;overflow-x:auto;overflow-y:auto}\n"], dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "component", type: MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "directive", type: MatCell, selector: "mat-cell, td[mat-cell]" }, { kind: "directive", type: MatCellDef, selector: "[matCellDef]" }, { kind: "directive", type: MatColumnDef, selector: "[matColumnDef]", inputs: ["matColumnDef"] }, { kind: "component", type: MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: MatHeaderCell, selector: "mat-header-cell, th[mat-header-cell]" }, { kind: "component", type: MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly", "disabledInteractive"], exportAs: ["matInput"] }, { kind: "directive", type: MatLabel, selector: "mat-label" }, { kind: "component", type: MatPaginator, selector: "mat-paginator", inputs: ["color", "pageIndex", "length", "pageSize", "pageSizeOptions", "hidePageSize", "showFirstLastButtons", "selectConfig", "disabled"], outputs: ["page"], exportAs: ["matPaginator"] }, { kind: "component", type: MatProgressBar, selector: "mat-progress-bar", inputs: ["color", "value", "bufferValue", "mode"], outputs: ["animationEnd"], exportAs: ["matProgressBar"] }, { kind: "component", type: MatRow, selector: "mat-row, tr[mat-row]", exportAs: ["matRow"] }, { kind: "directive", type: MatRowDef, selector: "[matRowDef]", inputs: ["matRowDefColumns", "matRowDefWhen"] }, { kind: "directive", type: MatSort, selector: "[matSort]", inputs: ["matSortActive", "matSortStart", "matSortDirection", "matSortDisableClear", "matSortDisabled"], outputs: ["matSortChange"], exportAs: ["matSort"] }, { kind: "component", type: MatSortHeader, selector: "[mat-sort-header]", inputs: ["mat-sort-header", "arrowPosition", "start", "disabled", "sortActionDescription", "disableClear"], exportAs: ["matSortHeader"] }, { kind: "component", type: MatTable, selector: "mat-table, table[mat-table]", exportAs: ["matTable"] }, { kind: "component", type: MatToolbar, selector: "mat-toolbar", inputs: ["color"], exportAs: ["matToolbar"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: MatHeaderCellDef, selector: "[matHeaderCellDef]" }, { kind: "directive", type: NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: MatIconButton, selector: "button[mat-icon-button]", exportAs: ["matButton"] }, { kind: "component", type: MatMenu, selector: "mat-menu", inputs: ["backdropClass", "aria-label", "aria-labelledby", "aria-describedby", "xPosition", "yPosition", "overlapTrigger", "hasBackdrop", "class", "classList"], outputs: ["closed", "close"], exportAs: ["matMenu"] }, { kind: "component", type: MatMenuItem, selector: "[mat-menu-item]", inputs: ["role", "disabled", "disableRipple"], exportAs: ["matMenuItem"] }, { kind: "directive", type: MatMenuTrigger, selector: "[mat-menu-trigger-for], [matMenuTriggerFor]", inputs: ["mat-menu-trigger-for", "matMenuTriggerFor", "matMenuTriggerData", "matMenuTriggerRestoreFocus"], outputs: ["menuOpened", "onMenuOpen", "menuClosed", "onMenuClose"], exportAs: ["matMenuTrigger"] }, { kind: "directive", type: MatListItemIcon, selector: "[matListItemIcon]" }, { kind: "component", type: MatHeaderRow, selector: "mat-header-row, tr[mat-header-row]", exportAs: ["matHeaderRow"] }, { kind: "directive", type: MatHeaderRowDef, selector: "[matHeaderRowDef]", inputs: ["matHeaderRowDef", "matHeaderRowDefSticky"] }, { kind: "directive", type: RouterLink, selector: "[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "info", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: MmOctoTableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'mm-octo-table', standalone: true, imports: [
                        AsyncPipe,
                        MatButton,
                        MatCell,
                        MatCellDef,
                        MatColumnDef,
                        MatFormField,
                        MatHeaderCell,
                        MatIcon,
                        MatInput,
                        MatLabel,
                        MatPaginator,
                        MatProgressBar,
                        MatRow,
                        MatRowDef,
                        MatSort,
                        MatSortHeader,
                        MatTable,
                        MatToolbar,
                        NgIf,
                        MatHeaderCellDef,
                        NgForOf,
                        MatIcon,
                        MatIconButton,
                        MatMenu,
                        MatMenuItem,
                        MatMenuTrigger,
                        MatIcon,
                        MatIcon,
                        MatListItemIcon,
                        MatHeaderRow,
                        MatHeaderRowDef,
                        MatHeaderRow,
                        MatHeaderRowDef,
                        MatButton,
                        MatIcon,
                        RouterLink,
                        MatIcon,
                        MatHeaderCellDef,
                        MatCellDef,
                        MatHeaderRowDef,
                        MatRowDef,
                        NgTemplateOutlet
                    ], template: "<div>\n  <mat-progress-bar *ngIf=\"loading || (dataSource?.loading$ | async)\" mode=\"indeterminate\"></mat-progress-bar>\n</div>\n\n<mat-toolbar class=\"octo-toolbar octo-detail-toolbar\">\n  @for (toolbarAction of leftToolbarActions; track toolbarAction) {\n  <button\n    mat-flat-button\n    routerLink=\"{{ toolbarAction.route }}\"\n    type=\"button\"\n    [disabled]=\"!toolbarAction.isDisabled ? false : (toolbarAction.isDisabled | async)\"\n  >\n    @if (toolbarAction?.svgIconName) {\n    <mat-icon class=\"svg-icon\" svgIcon=\"{{ toolbarAction.svgIconName }}\" matListItemIcon></mat-icon>\n    } @if (toolbarAction?.iconName) {\n    <mat-icon class=\"material-symbols-outlined\">{{ toolbarAction.iconName }}</mat-icon>\n    }\n    {{ toolbarAction.actionText }}\n  </button>\n  }\n\n  <div class=\"octo-spacer\"></div>\n\n  <div class=\"octo-toolbar-search\">\n    <mat-form-field appearance=\"outline\">\n      <mat-label>\n        <mat-icon class=\"material-symbols-outlined\">search</mat-icon>\n        Search\n      </mat-label>\n      <input #input matInput [disabled]=\"loading\" />\n    </mat-form-field>\n  </div>\n</mat-toolbar>\n\n<mat-table\n  [class.isMobile]=\"isMobile\"\n  [dataSource]=\"dataSource\"\n  class=\"mat-elevation-z8 table-container\"\n  mat-table\n  matSort\n  matSortActive=\"{{ defaultSortColumn }}\"\n  matSortDirection=\"asc\"\n  matSortDisableClear=\"true\"\n>\n  <ng-container *ngFor=\"let column of columns\" [matColumnDef]=\"getDisplayName(column)\">\n    <mat-header-cell *matHeaderCellDef mat-sort-header> {{ getDisplayName(column) }}</mat-header-cell>\n    <mat-cell *matCellDef=\"let element\">\n      <span *ngIf=\"isMobile\">{{ getDisplayName(column)}:</span>\n      @if (column.templateName) {\n      <ng-container *ngTemplateOutlet=\"getTemplate(column.templateName); context: { $implicit: element }\"> </ng-container>\n      } @else {\n      {{ accessElement(element, column) }}\n      }\n    </mat-cell>\n  </ng-container>\n\n  <!-- Consolidated Action Column with multiple buttons -->\n  <ng-container matColumnDef=\"actions\">\n    <mat-header-cell *matHeaderCellDef>Actions</mat-header-cell>\n    <mat-cell *matCellDef=\"let element\">\n      @for (column of actionColumns; track column) {\n      <ng-container>\n        <button mat-button (click)=\"emitRowData({ action: column.columnName, id: encodeURIComponent(element[currentId]), entry: element })\">\n          <mat-icon *ngIf=\"column?.svgIconName\" class=\"svg-icon\" svgIcon=\"{{ column.svgIconName }}\" matListItemIcon></mat-icon>\n          <mat-icon *ngIf=\"column?.iconName\" class=\"material-symbols-outlined\">{{ column.iconName }}</mat-icon>\n        </button>\n      </ng-container>\n      }\n\n      <!-- Options menu with additional actions -->\n      @if (optionActions.length > 0) {\n      <button mat-icon-button [matMenuTriggerFor]=\"menu\" aria-label=\"Options\">\n        <mat-icon class=\"material-symbols-outlined\">more_vert</mat-icon>\n      </button>\n      }\n\n      <mat-menu #menu=\"matMenu\">\n        @for (optionAction of optionActions; track optionAction) {\n        <ng-container>\n          <button\n            mat-menu-item\n            (click)=\"emitRowData({ action: optionAction.columnName, id: encodeURIComponent(element[currentId]), entry: element })\"\n          >\n            @if (optionAction?.svgIconName) {\n            <mat-icon class=\"svg-icon\" svgIcon=\"{{ optionAction.svgIconName }}\" matListItemIcon></mat-icon>\n            } @if (optionAction?.iconName) {\n            <mat-icon class=\"material-symbols-outlined\">{{ optionAction.iconName }}</mat-icon>\n            }\n            {{ optionAction.columnName }}\n          </button>\n        </ng-container>\n        }\n      </mat-menu>\n    </mat-cell>\n  </ng-container>\n\n  @if (hasActionColumns()) {\n  <mat-header-row *matHeaderRowDef=\"columnNames.concat(['actions'])\"></mat-header-row>\n  <mat-row *matRowDef=\"let row; columns: columnNames.concat(['actions'])\"></mat-row>\n  } @else {\n  <mat-header-row *matHeaderRowDef=\"columnNames\"></mat-header-row>\n  <mat-row *matRowDef=\"let row; columns: columnNames\"></mat-row>\n  }\n</mat-table>\n\n<mat-paginator\n  [length]=\"dataSource?.totalCount$ | async\"\n  (page)=\"selectedPageSizeChanged($event)\"\n  [pageSizeOptions]=\"pageSizeOptions\"\n  [pageSize]=\"selectedPageSizeSubject.getValue()\"\n></mat-paginator>\n", styles: [".table-container{display:block;width:100%;max-height:70vh;overflow-x:auto;overflow-y:auto}\n"] }]
        }], ctorParameters: () => [], propDecorators: { dataSource: [{
                type: Input
            }], cellTemplates: [{
                type: ContentChildren,
                args: [TemplateRef]
            }], actionColumns: [{
                type: Input
            }], leftToolbarActions: [{
                type: Input
            }], optionActions: [{
                type: Input
            }], searchFilterColumns: [{
                type: Input
            }], currentId: [{
                type: Input
            }], defaultSortColumn: [{
                type: Input
            }], rowIsClickable: [{
                type: Input
            }], pageSizeOptions: [{
                type: Input
            }], selectedPageSize: [{
                type: Input
            }], rowClicked: [{
                type: Output
            }], searchFilterStringUpdated: [{
                type: Output
            }], selectedRowId: [{
                type: Input
            }], actionColumnClick: [{
                type: Output
            }], columns: [{
                type: Input
            }], paginator: [{
                type: ViewChild,
                args: [MatPaginator, { static: false }]
            }], sort: [{
                type: ViewChild,
                args: [MatSort, { static: false }]
            }], input: [{
                type: ViewChild,
                args: ['input', { static: false }]
            }] } });

class MmOctoUiModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: MmOctoUiModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.14", ngImport: i0, type: MmOctoUiModule, imports: [MmOctoTableComponent], exports: [MmOctoTableComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: MmOctoUiModule, imports: [MmOctoTableComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: MmOctoUiModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        MmOctoTableComponent
                    ],
                    exports: [
                        MmOctoTableComponent
                    ]
                }]
        }] });

/*
 * Public API Surface of octo-ui
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ListElementModule, MmOctoTableComponent, MmOctoUiModule, OctoListNavigation, OctoListNavigationDataInfo, OctoListNavigationOptions, getDisplayName };
//# sourceMappingURL=meshmakers-octo-ui.mjs.map
